@@ -3,7 +3,7 @@ use warnings;
 
 package Net::OAuth2::Scheme::Factory;
 BEGIN {
-  $Net::OAuth2::Scheme::Factory::VERSION = '0.010005_005';
+  $Net::OAuth2::Scheme::Factory::VERSION = '0.020001_099';
 }
 # ABSTRACT: the default factory for token schemes
 
@@ -32,7 +32,7 @@ Net::OAuth2::Scheme::Factory - the default factory for token schemes
 
 =head1 VERSION
 
-version 0.010005_005
+version 0.020001_099
 
 =head1 SYNOPSIS
 
@@ -487,7 +487,7 @@ Choices are
 Use a "handle-style" bearer token where the token string is a random
 base64url string with no actual content.  Expiration information and
 all binding values must live in the vtable and need to be communicated
-out of band to the resource server.
+out of band to the resource server.  Implies C<< v_id => 'random' >>.
 
 =item C<'bearer_signed'>
 
@@ -510,7 +510,9 @@ C<'bearer_handle'> formatted tokens.
 
 =back
 
-The following options apply when C<< format => bearer_signed >> is selected and can be included with the C<bearer_signed_> prefix omitted (e.g., C<< transport => ['bearer_signed', hmac => 'hmac_sha256'] >>).
+The following options apply when C<< format => bearer_signed >> is
+selected and can be included with the C<bearer_signed_> prefix omitted
+(e.g., C<< transport => ['bearer_signed', hmac => 'hmac_sha256'] >>).
 
 =over
 
@@ -771,9 +773,9 @@ The actual cache object to use, some object that implements the L<Cache|Cache> i
 
 integer; setting this causes actual expiration times for items in the cache to be set this many seconds beyond the stated expiration time, i.e., so that the cache retains expired entries this much longer.  This also similarly extends the time that items are kept in the queue for C<< vtable_pull_queue => default >>.
 
-=item C<cache_prefix>  C<"vtab:">
+=item C<cache_prefix>
 
-a string that is prefixed to all vtable cache keys; if you are using this same cache for other purposes than holding vtable entries, make sure said other purposes use different prefixes or at least that I<this> prefix is chosen so that no vtable entry will be confused with an entry made for some other purpose.
+a string that is prefixed to all vtable cache keys.  If you are using this same cache for other purposes than holding vtable entries, make sure that said other purposes use different prefixes or at least that I<this> prefix is chosen so that no vtable entry will be confused with an entry made for some other purpose.  Default is C<"vtab:">.
 
 =back
 
@@ -793,20 +795,35 @@ one of
 
 =item C<< ['counter', I<tag> ] >>
 
-generate sequential IDs using a counter.  Providing I<tag> sets C<counter_tag> (which see).
+generate sequential IDs using a counter.
+Providing I<tag> sets C<counter_tag> (which see).
 
 =item C<'random'>
 
 =item C<< ['random', I<n> ] >>
 
-generate random IDs using the random number generator.  Providing I<n> sets C<v_id_random_length>.
+generate random IDs using the random number generator.  Providing I<n>
+sets C<v_id_random_length>, which needs to be large enough so as to
+make collisions between random IDs as unlikely as feasible over the
+lifetime of the tokens produced by this scheme.
 
 =back
 
+The default is C<'counter'> unless the scheme is one (e.g.,
+C<'bearer_handle'>) that explicitly requires unpredictable IDs.
+
+Note that random IDs currently begin with a 0-127 byte while counter
+IDs begin with a 128-255 byte, so no random ID should ever collide
+with a counter ID.  Likewise, counter IDs generated from the same
+C<counter_tag> are guaranteed not to collide.
+
 =item C<v_id_random_length>
 
-integer; for when C<< v_id => 'random' >>, the number of random bytes to
-include (must be at least 8).
+integer; for when C<< v_id => 'random' >>, the number of random bytes
+to use when creating the ID (must be at least 8).  Note that the ID
+ultimately created will generally be longer than this, both due to the
+possible inclusion of C<v_id_suffix> and any encoding (e.g.,
+base64url) that may be needed.
 
 =item C<counter_tag>
 
@@ -818,9 +835,9 @@ specified tag has not been seen before.
 
 (default C<''>) is added to the end of every ID generated in this
 scheme.  The main use of this is to distinguish (and thus prevent
-collisions between) IDs generated by multiple hosts for when there are
-to be multiple authorization servers issuing tokens for the same
-resource.
+collisions between) IDs generated by multiple hosts in the situation
+where there are multiple authorization servers issuing tokens for the
+same resource.
 
 =back
 
